@@ -69,6 +69,9 @@ class QCticAPI:
         self._host = host
         self._loop = None
 
+        if not self._host.endswith("/"):
+            self._host = f"{self._host}/"
+
     @property
     def loop(self):
         """asyncio.AbstractEventLoop: The event loop used by the sync methods of this class."""
@@ -121,6 +124,7 @@ class QCticAPI:
         return token or (user and passwd)
 
     def _build_url(self, part):
+        part = part if not part.startswith("/") else part[1:]
         return urljoin(self.host, part)
 
     def _clean_auth(self):
