@@ -1,9 +1,11 @@
 import asyncio
 import collections
 import logging
+import os
 import pprint
 import random
 import time
+import warnings
 from functools import wraps
 
 from qiskit.providers import BaseJob, JobError, JobStatus
@@ -13,6 +15,7 @@ from qctic.utils import wait_result, wait_result_async
 
 _PARAM_TIMEOUT = "timeout"
 _PARAM_WAIT = "wait"
+_ENV_SIM_RATIO = "QCTIC_SIMULATION_RATIO_WARNING"
 
 _logger = logging.getLogger(__name__)
 
@@ -55,6 +58,12 @@ WaitResultParams = collections.namedtuple(
     ["timeout", "wait"])
 
 
+class SimulationRatioWarning(Warning):
+    """Warning raised when the simulation ratio of any given job is too low. 
+    This usually means that it would be more optimal for the experiments to be executed 
+    locally to avoid paying the cost of network latencies and worker initialization."""
+
+
 class QCticJob(BaseJob):
     """A Qiskit job that is executed remotely in the CTIC Erwin simulation platform."""
 
@@ -75,6 +84,7 @@ class QCticJob(BaseJob):
         self._fetch_time = None
         self._run_params = run_params
         self._submit_task = None
+        self._raised_warning = False
 
     @property
     def api(self):
@@ -171,7 +181,7 @@ class QCticJob(BaseJob):
         including network latency, environment initialization and (optional) queue latency.
 
         Args:
-            include_queue (bool): (Optional) Take the queue latency into account.
+            queue (bool): (Optional) Take the queue latency into account.
 
         Returns:
             float: The simulation ratio.
@@ -211,6 +221,35 @@ class QCticJob(BaseJob):
         self._remote_job = await self.api.get_job(self.job_id())
         self._fetch_time = time.time()
 
+    def _raise_simulation_warning(self):
+        limit = os.getenv(_ENV_SIM_RATIO, None)
+
+        if self._raised_warning or limit is None:
+            return
+
+        ratio = self.get_simulation_ratio(queue=False)
+
+        if ratio is None:
+            return
+
+        try:
+            limit = float(limit)
+        except Exception as ex:
+            _logger.warning("Invalid sim. ratio value (%s): %s", limit, ex)
+            return
+
+        if ratio < limit:
+            warn_msg = (
+                "The simulation time ratio of this job ({}) "
+                "appears to be low (<{}). This is without taking "
+                "into account wait times in the queue. Please consider "
+                "running the simulation locally to optimize wait times."
+            ).format(ratio, limit)
+
+            _logger.warning(warn_msg)
+            warnings.warn(warn_msg, SimulationRatioWarning)
+            self._raised_warning = True
+
     def _result(self):
         error = self._remote_job.get("error", None)
 
@@ -221,9 +260,11 @@ class QCticJob(BaseJob):
         result = Result.from_dict(result_dict) if result_dict else None
 
         if result and not result.success:
-            _logger.warning(
-                "Some experiments failed:\n%s",
-                pprint.pformat([item.status for item in result.results]))
+            status_msg = pprint.pformat([r.status for r in result.results])
+            _logger.warning("Some experiments failed:\n%s", status_msg)
+
+        if result and result.success:
+            self._raise_simulation_warning()
 
         return result
 
