@@ -74,7 +74,7 @@ def _handler_create_job(backend_name, job_dict, assert_func=None):
 def _handler_get_job(job, job_dict):
     def handler(req):
         job_dict.update({
-            "qobj": job.qobj.to_dict(),
+            "qobj": job.qobj().to_dict(),
             "job_id": job.job_id()
         })
 
